pub fn capture_loopback(name: Option<&str>) -> Result<CaptureHandle>Expand description
Capture system audio playing on the output device name. If name is
None, captures the default output.
pub fn capture_loopback(name: Option<&str>) -> Result<CaptureHandle>Capture system audio playing on the output device name. If name is
None, captures the default output.